@@ -51,7 +51,7 @@ def processes(
 				"tty":tty,
 				"process":process,
 			}
-	return r3sponse.sucess_response(f"Successfully listed {len(processes)} processes." {
+	return r3sponse.sucess_response(f"Successfully listed {len(processes)} processes.", {
 		"processes":processes,
 	})
 
